@@ -11,17 +11,7 @@ from ...formats import FormatOptions, make_format_checker
 from ...utils import is_url_ish
 from ..errors import UnsupportedUrlScheme
 from .readers import HttpSchemaReader, LocalSchemaReader
-
-
-def _make_ref_resolver(
-    schema_uri: str | None, schema: dict
-) -> jsonschema.RefResolver | None:
-    if not schema_uri:
-        return None
-
-    base_uri = schema.get("$id", schema_uri)
-    # FIXME: temporary type-ignore beause typeshed has the type wrong
-    return jsonschema.RefResolver(base_uri, schema)  # type: ignore[arg-type]
+from .resolver import make_ref_resolver
 
 
 class SchemaLoaderBase:
@@ -30,7 +20,7 @@ class SchemaLoaderBase:
         instance_filename: str,
         instance_doc: dict[str, t.Any],
         format_opts: FormatOptions,
-    ):
+    ) -> jsonschema.Validator:
         raise NotImplementedError
 
 
@@ -40,7 +30,7 @@ class SchemaLoader(SchemaLoaderBase):
         schemafile: str,
         cache_filename: str | None = None,
         disable_cache: bool = False,
-    ):
+    ) -> None:
         # record input parameters (these are not to be modified)
         self.schemafile = schemafile
         self.cache_filename = cache_filename
@@ -55,7 +45,7 @@ class SchemaLoader(SchemaLoaderBase):
         self._reader: LocalSchemaReader | HttpSchemaReader | None = None
 
         # setup a location to store the validator so that it is only built once by default
-        self._validator = None
+        self._validator: jsonschema.Validator | None = None
 
     @property
     def reader(self) -> LocalSchemaReader | HttpSchemaReader:
@@ -85,7 +75,7 @@ class SchemaLoader(SchemaLoaderBase):
     def get_schema(self) -> dict[str, t.Any]:
         return self.reader.read_schema()
 
-    def make_validator(self, format_opts: FormatOptions):
+    def make_validator(self, format_opts: FormatOptions) -> jsonschema.Validator:
         schema_uri = self.get_schema_ref_base()
         schema = self.get_schema()
 
@@ -96,7 +86,7 @@ class SchemaLoader(SchemaLoaderBase):
         # if the location is a URL, there's no change, but if it's a file path
         # it's made absolute and URI-ized
         # the resolver should use `$id` if there is one present in the schema
-        ref_resolver = _make_ref_resolver(schema_uri, schema)
+        ref_resolver = make_ref_resolver(schema_uri, schema)
 
         # get the correct validator class and check the schema under its metaschema
         validator_cls = jsonschema.validators.validator_for(schema)
@@ -108,14 +98,14 @@ class SchemaLoader(SchemaLoaderBase):
             resolver=ref_resolver,
             format_checker=format_checker,
         )
-        return validator
+        return t.cast(jsonschema.Validator, validator)
 
     def get_validator(
         self,
         instance_filename: str,
         instance_doc: dict[str, t.Any],
         format_opts: FormatOptions,
-    ):
+    ) -> jsonschema.Validator:
         self._validator = self.make_validator(format_opts)
         return self._validator
 
@@ -137,19 +127,6 @@ class MetaSchemaLoader(SchemaLoaderBase):
         instance_filename: str,
         instance_doc: dict[str, t.Any],
         format_opts: FormatOptions,
-    ):
+    ) -> jsonschema.Validator:
         validator = jsonschema.validators.validator_for(instance_doc)
-        return validator(validator.META_SCHEMA)
-
-
-def schema_loader_from_args(args) -> SchemaLoaderBase:
-    if args.schemafile is not None:
-        return SchemaLoader(
-            args.schemafile,
-            args.cache_filename,
-            args.no_cache,
-        )
-    elif args.builtin_schema:
-        return BuiltinSchemaLoader(args.builtin_schema)
-    else:
-        return MetaSchemaLoader()
+        return t.cast(jsonschema.Validator, validator(validator.META_SCHEMA))
